==> rc-ui-lib-2.0.3.tgz: package/lib/sidebar/SidebarItem.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_classnames = __toESM(require("classnames"));
var import_badge = require("../badge");
var import_ConfigProviderContext = __toESM(require("../config-provider/ConfigProviderContext"));
var import_SidebarContext = __toESM(require("./SidebarContext"));
const SidebarItem = (props) => {
  const {
    prefixCls,
    createNamespace
  } = (0, import_react.useContext)(import_ConfigProviderContext.default);
  const [bem] = createNamespace("sidebar-item", prefixCls);
  const parent = (0, import_react.useContext)(import_SidebarContext.default);
  if (!Object.prototype.hasOwnProperty.call(parent, "getActive")) {
    if (process.env.NODE_ENV !== "production") {
      console.error("[rc-ui-lib] <SidebarItem> must be a child component of <Sidebar>.");
    }
    return null;
  }
  const {
    dot,
    badge,
    title,
    disabled,
    index
  } = props;
  const selected = index === parent.getActive();
  const onClick = () => {
    var _a;
    if (props.disabled) {
      return;
    }
    (_a = props.onClick) == null ? void 0 : _a.call(props, index);
    parent.setActive(index);
  };
  return /* @__PURE__ */ import_react.default.createElement("div", {
    role: "tab",
    tabIndex: disabled ? void 0 : 0,
    className: (0, import_classnames.default)(bem({
      select: selected,
      disabled
    })),
    "aria-selected": selected,
    onClick
  }, /* @__PURE__ */ import_react.default.createElement(import_badge.Badge, {
    dot,
    content: badge,
    className: (0, import_classnames.default)(bem("text"))
  }, props.children ? props.children : title));
};
var stdin_default = SidebarItem;

==> rc-ui-lib-2.1.1.tgz: package/lib/sidebar/SidebarItem.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  default: () => stdin_default
});
module.exports = __toCommonJS(stdin_exports);
var import_react = __toESM(require("react"));
var import_classnames = __toESM(require("classnames"));
var import_badge = require("../badge");
var import_ConfigProviderContext = __toESM(require("../config-provider/ConfigProviderContext"));
var import_SidebarContext = __toESM(require("./SidebarContext"));
const SidebarItem = (props) => {
  const {
    prefixCls,
    createNamespace
  } = (0, import_react.useContext)(import_ConfigProviderContext.default);
  const [bem] = createNamespace("sidebar-item", prefixCls);
  const parent = (0, import_react.useContext)(import_SidebarContext.default);
  if (!Object.prototype.hasOwnProperty.call(parent, "getActive")) {
    if (process.env.NODE_ENV !== "production") {
      console.error("[rc-ui-lib] <SidebarItem> must be a child component of <Sidebar>.");
    }
    return null;
  }
  const {
    dot,
    badge,
    title,
    disabled,
    index
  } = props;
  const selected = index === parent.getActive();
  const onClick = () => {
    var _a;
    if (props.disabled) {
      return;
    }
    (_a = props.onClick) == null ? void 0 : _a.call(props, index);
    parent.setActive(index);
  };
  return (
    // eslint-disable-next-line jsx-a11y/interactive-supports-focus
    /* @__PURE__ */ import_react.default.createElement("div", {
      role: "tab",
      tabIndex: disabled ? void 0 : 0,
      className: (0, import_classnames.default)(bem({
        select: selected,
        disabled
      })),
      "aria-selected": selected,
      onClick
    }, /* @__PURE__ */ import_react.default.createElement(import_badge.Badge, {
      dot,
      content: badge,
      className: (0, import_classnames.default)(bem("text"))
    }, props.children ? props.children : title))
  );
};
var stdin_default = SidebarItem;
